@@ -15,7 +15,7 @@ import plotly.express as px
 
 class Surface:
     def __init__(self, df, datestr, putcall, symbol):
-        self.df = df.sort_values("delta")
+        self.df = df.sort_values(["delta", "strike"], ascending=[putcall == "C"] * 2)
         self.day = datestr
         self.putCall = putcall
         self.symbol = symbol
@@ -27,7 +27,11 @@ class Surface:
             temp = self.df.query("dte == @dte")
             desc = f"{self.symbol} {self.putCall} \n Date: {self.day} \n dte: {dte}"
             curve = Curve(
-                temp.markIv.values, temp.delta.values, temp.dte, temp.strike, desc
+                temp.markIv.values,
+                temp.delta.values,
+                temp.dte,
+                temp.strike.values,
+                desc,
             )
             self.curves.append(curve)
 
